@@ -86,16 +86,16 @@ class PseudocodefrLexer(RegexLexer):
                     (r'[\s]+', Text)
             ],
             'core':[ # Statements
-                    (r'\b(debut|début|fin|si|alors|sinon|fin[_ ]si|tant[ _]que|tantque|fin[ _]tantque|faire|répéter|'
-                    r'repeter|type|structure|fin[ _]structure|fonction|procédure|procedure|retourner|renvoyer|'
-                    r'pour|variant|allant|de|fin[ _]pour|à|déclarations?|jusque|spécialise|specialise|comporte|super|public|privé|protégé|'
+                    (r'\b(debut|début|fin|si|alors|sinon|fin[_ ]?si|tant[ _]?que|tantque|fin[ _]?tant[ _]?que|faire|répéter|'
+                    r'repeter|type|structure|fin[ _]?structure|fonction|procédure|procedure|retourner|renvoyer|'
+                    r'pour|variant|allant|de|fin[ _]?pour|à|déclarations?|jusque|spécialise|specialise|comporte|super|public|privé|protégé|'
                     r'est|vaut|prend la valeur|affecter|'
                     r'classe'
                     r')\s*\b', Keyword),
 
                     # Data Types
                     (r'\b(entiers?|chaines?|chaînes?|réels?|reels?|flottants?|caractères?|caracteres?|booléens?|'
-                    r'booleens?|tableaux?|listes?|files?|piles?|rien)\s*\b', 
+                    r'booleens?|tableaux?|listes?|files?|piles?|verrous?|sémaphores?|semaphores?|rien)\s*\b', 
                     Keyword.Type),
 
                     # Greek Letters Replace
